pro tsys_replace

common global
common data_set

; tsys_replace.pro
;
; This procedure replaces the Tsys values for one antenna by the Tsys 
; values for another. 
; 
; May only be used AFTER the procedure tsys_ant has been used to calculate
; antenna-based Tsys (stored in bl[pbf].csnr and bl[pbf].cnoise)
;
; After running this procedure, you can run tsys_bsl to replace the 
; baseline-based values with the corrected Tsys. 
;
; mhughes 27Jan07 

print,'*************************************************************'
print,'Tsys_replace.pro'
print,'*************************************************************'
print,'Replace Tsys values for antenna x with values from antenna y:'
badant=0
goodant=0
read,badant,prompt='x = '
read,goodant,prompt='y = '

result=dat_filter(s_f,/reset,/no_notify)
if (bl[pbf[0]].csnr le 40.) or (bl[pbf[0]].cnoise le 40.) then begin
   print,'You need run tsys_ant first before using this program.'
   print,'Quit !'
   return
endif

; setting up: finding out which antennas are in the array
subset1=bl[pbf].itel1
subset2=bl[pbf].itel2
subset=[subset1,subset2]
ants=subset(uniq(subset, sort(subset)))
nants=n_elements(ants)

; using baseline goodant-badant to get Tsys for goodant for all ints
if goodant gt badant then begin
  loc=where(bl[pbf].itel1 eq badant and bl[pbf].itel2 eq goodant,count)
  if count eq 0 then begin
     print,'Wrong antenna numbers !'
     print,'Failed!'
     return
  endif
  tgood=bl[pbf[loc]].cnoise
endif else begin
  loc=where(bl[pbf].itel1 eq goodant and bl[pbf].itel2 eq badant,count)
  if count eq 0 then begin
     print,'Wrong antenna numbers !'
     print,'Failed!'
     return
  endif
  tgood=bl[pbf[loc]].csnr
endelse

; looping through baselines and replacing badant values with goodant values
for i=0,nants-2 do begin
  for j=i+1,nants-1 do begin
    loc=where(bl[pbf].itel1 eq ants(i) and bl[pbf].itel2 eq ants(j))
    if ants(i) eq badant then bl[pbf[loc]].csnr=tgood
    if ants(j) eq badant then bl[pbf[loc]].cnoise=tgood
  endfor
endfor

print,'FINISHED!'
return
end
